pyxmpp.streambase

Package pyxmpp :: Module streambase |
[hide private]

# Module streambase

source code

Core XMPP stream functionality.

Normative reference:
  - RFC 3920

Classes | [hide private]
| StreamBase Base class for a generic XMPP stream.

Functions | [hide private]
stanza_factory(xmlnode, stream=None) Creates Iq, Message or Presence object for XML stanza `xmlnode` | source code

Variables | [hide private]
| __revision__ = ``'``$Id: streambase.py 700 2010-04-03 15:34:59Z ja``...``
| STREAM_NS = ``'``http://etherx.jabber.org/streams``'``
| BIND_NS = ``'``urn:ietf:params:xml:ns:xmpp-bind``'``
| __package__ = ``'``pyxmpp``'``

Imports: libxml2, socket, os, time, random, threading, errno, logging, xmlextra, ExpiringDictionary, to_utf8, Stanza, StreamErrorNode, Iq, Presence, Message, JID, resolver, StanzaProcessor, StreamError, StreamEncryptionRequired, HostMismatch, ProtocolError, FatalStreamError, StreamParseError, StreamAuthenticationError

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: streambase.py 700 2010-04-03 15:34:59Z jajcus $'